"""
Copyright 2021-2024 MICRORISC s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
from Setter.InfluxDbBridgeConfig import InfluxDbBridgeConfig
from Setter.IqarosConfig import IqarosConfig


class IqarosV2Config(IqarosConfig):
	"""
	IQAROS version 2 gateway configuration class.

	Methods
	-------
	configure() -> None:
		Configure IQAROS gateway.
	get_services() -> list[str]:
		Return IQAROS services to restart.
	"""

	@classmethod
	def configure(cls) -> None:
		"""
		Configure IQAROS gateway.

		Returns
		-------
		None
		"""
		InfluxDbBridgeConfig.configure(generic_iqaros=True)

	@classmethod
	def get_services(cls) -> list[str]:
		"""
		Return IQAROS services to restart.

		Returns
		-------
		list[str]
			IQAROS services to restart
		"""
		return [
			'iqrf-gateway-influxdb-bridge',
		]
