"""
Copyright 2021-2024 MICRORISC s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from logging import Logger

from Setter.Logging import Logging
from Setter.Common.ServiceManager import ServiceManager, ServiceErrorException


class IqrfCloudConfig:
	"""
	IQRF Cloud configuration class.

	Methods
	-------
	configure() -> None:
		Configure connection to IQRF Cloud.
	"""

	__logger: Logger = Logging.get_logger()
	__service_provisioning: str = 'iqrf-cloud-provisioning'

	@classmethod
	def configure(cls) -> None:
		"""
		Configure connection to IQRF Cloud.

		Returns
		-------
		None
		"""
		cls.__logger.info('Configuring IQRF Cloud.')
		if not ServiceManager.exists(cls.__service_provisioning):
			cls.__logger.warning('IQRF Cloud provisioning service not found.')
			return
		try:
			ServiceManager.start(cls.__service_provisioning)
			cls.__logger.info('Connection to IQRF Cloud has been configured.')
		except ServiceErrorException as service_error:
			cls.__logger.error('Failed to start IQRF Cloud provisioning. Error: %s', service_error.message)
